==> owncloud-8.1.0p2.tgz: owncloud/apps/encryption/l10n/uk.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Відсутній пароль ключа відновлення",
    "Please repeat the recovery key password" : "Введіть ще раз пароль для ключа відновлення",
    "Repeated recovery key password does not match the provided recovery key password" : "Введені паролі ключа відновлення не співпадають",
    "Recovery key successfully enabled" : "Ключ відновлення підключено",
    "Could not enable recovery key. Please check your recovery key password!" : "Не вдалося підключити ключ відновлення. Будь ласка, перевірте пароль свого ключа відновлення!",
    "Recovery key successfully disabled" : "Ключ відновлення відключено",
    "Could not disable recovery key. Please check your recovery key password!" : "Не вдалося відключити ключ відновлення. Будь ласка, перевірте пароль ключа відновлення!",
    "Missing parameters" : "Відсутні параметри",
    "Please provide the old recovery password" : "Будь ласка, введіть старий пароль відновлення",
    "Please provide a new recovery password" : "Будь ласка, введіть новий пароль відновлення",
    "Please repeat the new recovery password" : "Будь ласка, введіть новий пароль відновлення ще раз",
    "Password successfully changed." : "Пароль змінено.",
    "Could not change the password. Maybe the old password was not correct." : "Не вдалося змінити пароль. Можливо ви неправильно ввели старий пароль.",
    "Recovery Key disabled" : "Ключ відновлення відключений",
    "Recovery Key enabled" : "Відновлення ключа увімкнено",
    "Could not enable the recovery key, please try again or contact your administrator" : "Не вдалося підключити ключ відновлення, будь ласка, перевірте пароль ключа відновлення!",
    "Could not update the private key password." : "Не вдалося оновити пароль секретного ключа.",
    "The old password was not correct, please try again." : "Старий пароль введено не вірно, спробуйте ще раз.",
    "The current log-in password was not correct, please try again." : "Невірний пароль входу, будь ласка, спробуйте ще раз.",
    "Private key password successfully updated." : "Пароль секретного ключа оновлено.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Невірний закритий ключ для доданку шифрування. Оновіть пароль до вашого закритого ключа в особистих налаштуваннях.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Доданок шифрування ввімкнено, але ваші ключі не ініціалізовано, вийдіть та зайдіть знову",
    "Encryption App is enabled and ready" : "Додаток кодування дозволений і готовий",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Не можу розшифрувати цей файл, можливо він опублікований. Будь ласка, попросіть власника опублікувати його заново.",
    "Enable recovery key" : "Увімкнути ключ відновлення",
    "Disable recovery key" : "Вимкнути ключ відновлення",
    "Recovery key password" : "Пароль ключа відновлення",
    "Repeat recovery key password" : "Повторіть пароль ключа відновлення",
    "Change recovery key password:" : "Змінити пароль ключа відновлення:",
    "Old recovery key password" : "Старий пароль ключа відновлення",
    "New recovery key password" : "Новий пароль ключа відновлення",
    "Repeat new recovery key password" : "Повторіть новий пароль ключа відновлення",
    "Change Password" : "Змінити Пароль",
    "ownCloud basic encryption module" : "базовий модуль шифрування ownCloud",
    "Your private key password no longer matches your log-in password." : "Пароль вашого закритого ключа більше не відповідає паролю від вашого облікового запису.",
    "Set your old private key password to your current log-in password:" : "Замініть старий пароль від закритого ключа на новий пароль входу:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Якщо ви не пам'ятаєте ваш старий пароль, ви можете звернутися до адміністратора щоб його відновити.",
    "Old log-in password" : "Старий пароль входу",
    "Current log-in password" : "Поточний пароль входу",
    "Update Private Key Password" : "Оновити пароль для закритого ключа",
    "Enable password recovery:" : "Ввімкнути відновлення паролю:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Включення цієї опції дозволить вам отримати доступ до своїх зашифрованих файлів у випадку втрати паролю",
    "Enabled" : "Увімкнено",
    "Disabled" : "Вимкнено"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/encryption/l10n/uk.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Відсутній пароль ключа відновлення",
    "Please repeat the recovery key password" : "Введіть ще раз пароль для ключа відновлення",
    "Repeated recovery key password does not match the provided recovery key password" : "Введені паролі ключа відновлення не співпадають",
    "Recovery key successfully enabled" : "Ключ відновлення підключено",
    "Could not enable recovery key. Please check your recovery key password!" : "Не вдалося підключити ключ відновлення. Будь ласка, перевірте пароль свого ключа відновлення!",
    "Recovery key successfully disabled" : "Ключ відновлення відключено",
    "Could not disable recovery key. Please check your recovery key password!" : "Не вдалося відключити ключ відновлення. Будь ласка, перевірте пароль ключа відновлення!",
    "Missing parameters" : "Відсутні параметри",
    "Please provide the old recovery password" : "Будь ласка, введіть старий пароль відновлення",
    "Please provide a new recovery password" : "Будь ласка, введіть новий пароль відновлення",
    "Please repeat the new recovery password" : "Будь ласка, введіть новий пароль відновлення ще раз",
    "Password successfully changed." : "Пароль змінено.",
    "Could not change the password. Maybe the old password was not correct." : "Не вдалося змінити пароль. Можливо ви неправильно ввели старий пароль.",
    "Recovery Key disabled" : "Ключ відновлення відключений",
    "Recovery Key enabled" : "Відновлення ключа увімкнено",
    "Could not enable the recovery key, please try again or contact your administrator" : "Не вдалося підключити ключ відновлення, будь ласка, перевірте пароль ключа відновлення!",
    "Could not update the private key password." : "Не вдалося оновити пароль секретного ключа.",
    "The old password was not correct, please try again." : "Старий пароль введено не вірно, спробуйте ще раз.",
    "The current log-in password was not correct, please try again." : "Невірний пароль входу, будь ласка, спробуйте ще раз.",
    "Private key password successfully updated." : "Пароль секретного ключа оновлено.",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Невірний закритий ключ для доданку шифрування. Оновіть пароль до вашого закритого ключа в особистих налаштуваннях.",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Доданок шифрування ввімкнено, але ваші ключі не ініціалізовано, вийдіть та зайдіть знову",
    "Encryption App is enabled and ready" : "Додаток кодування дозволений і готовий",
    "one-time password for server-side-encryption" : "одноразовий пароль для шифрування на сервері",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Не можу розшифрувати цей файл, можливо він опублікований. Будь ласка, попросіть власника опублікувати його заново.",
    "The share will expire on %s." : "Спільний доступ закінчиться %s.",
    "Cheers!" : "Будьмо!",
    "Enable recovery key" : "Увімкнути ключ відновлення",
    "Disable recovery key" : "Вимкнути ключ відновлення",
    "Recovery key password" : "Пароль ключа відновлення",
    "Repeat recovery key password" : "Повторіть пароль ключа відновлення",
    "Change recovery key password:" : "Змінити пароль ключа відновлення:",
    "Old recovery key password" : "Старий пароль ключа відновлення",
    "New recovery key password" : "Новий пароль ключа відновлення",
    "Repeat new recovery key password" : "Повторіть новий пароль ключа відновлення",
    "Change Password" : "Змінити Пароль",
    "ownCloud basic encryption module" : "базовий модуль шифрування ownCloud",
    "Your private key password no longer matches your log-in password." : "Пароль вашого закритого ключа більше не відповідає паролю від вашого облікового запису.",
    "Set your old private key password to your current log-in password:" : "Замініть старий пароль від закритого ключа на новий пароль входу:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Якщо ви не пам'ятаєте ваш старий пароль, ви можете звернутися до адміністратора щоб його відновити.",
    "Old log-in password" : "Старий пароль входу",
    "Current log-in password" : "Поточний пароль входу",
    "Update Private Key Password" : "Оновити пароль для закритого ключа",
    "Enable password recovery:" : "Ввімкнути відновлення паролю:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Включення цієї опції дозволить вам отримати доступ до своїх зашифрованих файлів у випадку втрати паролю",
    "Enabled" : "Увімкнено",
    "Disabled" : "Вимкнено"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
